@@ -1,6 +1,10 @@
 class Array
 	def count()
-		nitems()
+		if defined? nitems
+			return nitems
+		else
+			return super
+		end
 	end
 	def find_index(idx)
 		index(idx)
