@@ -136,11 +136,18 @@ class Eat::Aria2 < GLib::Object
 					command = "aria2c --enable-xml-rpc --xml-rpc-listen-all --xml-rpc-listen-port=#{@port} " \
 						"--conf-path=#{@confdir}/aria2.conf --log=#{@confdir}/aria2.log --log-level=notice"
 					@@pid = spawn_server(command)
+				rescue Timeout::Error
+				begin
+					# Retry with even fewer arguments for aria2 < 1.6
+					command = "aria2c --enable-xml-rpc --xml-rpc-listen-port=#{@port} " \
+						"--conf-path=#{@confdir}/aria2.conf --log=#{@confdir}/aria2.log --log-level=notice"
+					@@pid = spawn_server(command)
 				rescue Timeout::Error
 					@@pid = 0
 					raise "Failed to get positive response from aria2"
 				end
 				end
+				end
 				# Store pid in a file
 				begin
 					File.open(@confdir+"/aria2.pid", "w").puts(@@pid)
@@ -157,6 +164,10 @@ class Eat::Aria2 < GLib::Object
 		end
 	end
 
+=begin
+	spawn_server:
+	Execute an aria2c process in background and wait for a positive response.
+=end
 	def spawn_server(command)
 		pid = Process.spawn(command, :pgroup=>true, :chdir=>ENV['HOME'],
 				STDOUT=>"/dev/null", STDIN=>"/dev/null")
@@ -166,7 +177,7 @@ class Eat::Aria2 < GLib::Object
 		Timeout::timeout(5) do
 			begin
 				begin
-					result = @@client.call("aria2.getVersion")
+					result = @@client.call("aria2.tellActive")
 				rescue
 				end
 				sleep 1 if result == nil
@@ -176,6 +187,10 @@ class Eat::Aria2 < GLib::Object
 		pid
 	end
 
+=begin
+	call:
+	Make an XML-RPC call to the server. Try to connect if the connection is broken.
+=end
 	def call(method, *args)
 		begin
 			result = @@client.call(method, *args)
@@ -221,9 +236,11 @@ class Eat::Aria2 < GLib::Object
 				@@client = XMLRPC::Client.new3({:host => @hostname, :path => "/rpc",
 						:port => @port, :user => @user, :password => @password,
 						:timeout => 60})
-				result = call("aria2.getVersion")
+				result = call("aria2.tellActive")
 				raise Exception.new("Unable to connect to aria2 XML-RPC server") if result == nil
-				@version = result["version"]
+				# aria2 1.4 doesn't provide aria2.getVersion method
+				result = call("aria2.getVersion")
+				@version = result != nil ? result["version"] : "1.4"
 				@is_connected = true
 				signal_emit("connected")
 			rescue Exception => e
@@ -259,7 +276,7 @@ class Eat::Aria2 < GLib::Object
 	end
 
 	def use_local_server?()
-		@use_local_server and @@pid > 0
+		@use_local_server
 	end
 
 =begin
@@ -288,25 +305,37 @@ class Eat::Aria2 < GLib::Object
 	end
 
 	# Adds new HTTP(S)/FTP/BitTorrent/Magnet URI.
-	def add_uri(uris, options = nil, position = nil)
+	def add_uri(uris, options = [], position = nil)
 		uris = [ uris ] if uris.class == String
-		gid = call("aria2.addUri", uris)
+		if position != nil
+			gid = call("aria2.addUri", uris, options, position)
+		else
+			gid = call("aria2.addUri", uris, options)
+		end
 		@new_downloads << gid if gid != nil
 		gid
 	end
 
 	# Adds BitTorrent download by uploading .torrent file.
-	def add_torrent(torrent, uris = nil, options = nil, position = nil)
+	def add_torrent(torrent, uris = [], options = [], position = nil)
 		data = read(torrent)
-		gid = call("aria2.addTorrent", XMLRPC::Base64.new(data))
+		if position != nil
+			gid = call("aria2.addTorrent", XMLRPC::Base64.new(data), uris, options, position)
+		else
+			gid = call("aria2.addTorrent", XMLRPC::Base64.new(data), uris, options)
+		end
 		@new_downloads << gid if gid != nil
 		gid
 	end
 
 	# Adds Metalink download by uploading .metalink file.
-	def add_metalink(metalink, options = nil, position = nil)
+	def add_metalink(metalink, options = [], position = nil)
 		data = read(metalink)
-		gid = call("aria2.addMetalink", XMLRPC::Base64.new(data))
+		if position != nil
+			gid = call("aria2.addMetalink", XMLRPC::Base64.new(data), options, position)
+		else
+			gid = call("aria2.addMetalink", XMLRPC::Base64.new(data), options)
+		end
 		@new_downloads << gid if gid != nil
 		gid
 	end
